==> ecs-1.60.0-sources.jar: software/amazon/awscdk/services/ecs/PlacementConstraint.java <==
package software.amazon.awscdk.services.ecs;

/**
 * The placement constraints to use for tasks in the service. For more information, see [Amazon ECS Task Placement Constraints](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-placement-constraints.html).
 * <p>
 * Tasks will only be placed on instances that match these rules.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:33.033Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.PlacementConstraint")
public class PlacementConstraint extends software.amazon.jsii.JsiiObject {

    protected PlacementConstraint(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected PlacementConstraint(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Use distinctInstance to ensure that each task in a particular group is running on a different container instance.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.PlacementConstraint distinctInstances() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.PlacementConstraint.class, "distinctInstances", software.amazon.awscdk.services.ecs.PlacementConstraint.class);
    }

    /**
     * Use memberOf to restrict the selection to a group of valid candidates specified by a query expression.
     * <p>
     * Multiple expressions can be specified. For more information, see
     * <a href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/cluster-query-language.html">Cluster Query Language</a>.
     * <p>
     * You can specify multiple expressions in one call. The tasks will only be placed on instances matching all expressions.
     * <p>
     * @see https://docs.aws.amazon.com/AmazonECS/latest/developerguide/cluster-query-language.html
     * @param expressions This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.PlacementConstraint memberOf(final @org.jetbrains.annotations.NotNull java.lang.String... expressions) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.PlacementConstraint.class, "memberOf", software.amazon.awscdk.services.ecs.PlacementConstraint.class, java.util.Arrays.<Object>stream(expressions).toArray(Object[]::new));
    }

    /**
     * Return the placement JSON.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.ecs.CfnService.PlacementConstraintProperty> toJson() {
        return java.util.Collections.unmodifiableList(this.jsiiCall("toJson", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.CfnService.PlacementConstraintProperty.class))));
    }
}

==> ecs-1.100.0-sources.jar: software/amazon/awscdk/services/ecs/PlacementConstraint.java <==
package software.amazon.awscdk.services.ecs;

/**
 * The placement constraints to use for tasks in the service. For more information, see [Amazon ECS Task Placement Constraints](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-placement-constraints.html).
 * <p>
 * Tasks will only be placed on instances that match these rules.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:41.833Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.PlacementConstraint")
public class PlacementConstraint extends software.amazon.jsii.JsiiObject {

    protected PlacementConstraint(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected PlacementConstraint(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Use distinctInstance to ensure that each task in a particular group is running on a different container instance.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.PlacementConstraint distinctInstances() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.PlacementConstraint.class, "distinctInstances", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.PlacementConstraint.class));
    }

    /**
     * Use memberOf to restrict the selection to a group of valid candidates specified by a query expression.
     * <p>
     * Multiple expressions can be specified. For more information, see
     * <a href="https://docs.aws.amazon.com/AmazonECS/latest/developerguide/cluster-query-language.html">Cluster Query Language</a>.
     * <p>
     * You can specify multiple expressions in one call. The tasks will only be placed on instances matching all expressions.
     * <p>
     * @see https://docs.aws.amazon.com/AmazonECS/latest/developerguide/cluster-query-language.html
     * @param expressions This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.PlacementConstraint memberOf(final @org.jetbrains.annotations.NotNull java.lang.String... expressions) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.PlacementConstraint.class, "memberOf", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.PlacementConstraint.class), java.util.Arrays.<Object>stream(expressions).toArray(Object[]::new));
    }

    /**
     * Return the placement JSON.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.ecs.CfnService.PlacementConstraintProperty> toJson() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.call(this, "toJson", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.CfnService.PlacementConstraintProperty.class))));
    }
}
